@@ -7,6 +7,7 @@ from pymultirole_plugins.v1.schema import Document, Sentence
 
 class ReadingGridParameters(ProcessorParameters):
     separator: str = Field("", description="Separator to append to the remaining sentences")
+    min_annotations: int = Field(1, description="The minimum number of annotations required to keep the sentence.")
 
 
 class ReadingGridProcessor(ProcessorBase):
@@ -36,7 +37,7 @@ class ReadingGridProcessor(ProcessorBase):
                     sentence_map[a.start].append(a)
                 for sent in sentence_map.ranges():
                     ann_list = sent.value
-                    if ann_list:
+                    if ann_list and len(ann_list) >= params.min_annotations:
                         sstart = start
                         send = sstart + (sent.stop - sent.start)
                         sentences.append(Sentence(start=sstart, end=send))
